Install and configure
~~~~~~~~~~~~~~~~~~~~~

This section describes how to install and configure the networking-ansible
ML2 Driver, code-named networking-ansible, on the controller node.
This section assumes that you already have a working OpenStack
environment with Neutron server included.

Perform installation configuration steps on each controller node that has a Neutron server running.

.. toctree::
   :maxdepth: 2

   prerequisites.rst
   install.rst
   configure.rst
   verify.rst
   next-steps.rst

.. note::

   Installation and configuration may vary by distribution.

This chapter assumes a working setup of OpenStack that includes Neutron server.
For guides to assist in installing and deploying OpenStack visit
`OpenStack Docs <https://docs.openstack.org/>`_.

